import React, { useEffect, useState } from 'react'
import axios from 'axios'
import { Link, useParams } from 'react-router-dom'
import { API_BASE_URL } from '../config'
import TagSearch from './TagSearch'

type Tag = { id:        number
             name:      string
             category:  string }

type TagByCategory = { [key: string]: Tag[] }

type OriginalTag = { id:        number
                     name:      string
                     category:  string }

type Post = { id:         number
              url:        string
              title:      string
              thumbnail:  string
              tags:       Tag[] }

type Props = { posts:     Post[]
               setPosts:  (posts: Post[]) => void }


const tagNameMap: { [key: string]: string } = {
    general:    '一般',
    deerjikist: 'ニジラー',
    nico:       'ニコニコタグ' }

const TagSidebar: React.FC = (props: Props) => {
  const { posts, setPosts } = props

  const [tags, setTags] = useState<TagByCategory> ({ })
  const [tagsCounts, setTagsCounts] = useState<{ [key: id]: number }> ({ })

  useEffect (() => {
    const fetchTags = async () => {
      try
      {
        let tagsTmp: TagByCategory = { }
        let tagsCountsTmp: { [key: id]: number } = { }
        for (const post of posts)
          {
            for (const tag of post.tags)
              {
                if (!(tag.category in tagsTmp))
                  tagsTmp[tag.category] = []
                tagsTmp[tag.category].push (tag)
                if (!(tag.id in tagsCountsTmp))
                  tagsCountsTmp[tag.id] = 0
                ++tagsCountsTmp[tag.id]
              }
          }
        for (const cat of Object.keys (tagsTmp))
          tagsTmp[cat].sort ((tagA, tagB) => tagA.name < tagB.name ? -1 : 1)
        setTags (tagsTmp)
        setTagsCounts (tagsCountsTmp)
      }
      catch (error)
      {
        console.error ('Failed to fetch tags:', error)
      }
    }

    fetchTags ()
  }, [posts])

  return (
      <div className="w-64 bg-gray-100 p-4 border-r border-gray-200 h-full">
        <TagSearch />
        {['general', 'deerjikist', 'nico'].map (cat => cat in tags && <>
            <h2>{tagNameMap[cat]}</h2>
            <ul>
              {tags[cat].map (tag => (
                  <li key={tag.id} className="mb-2">
                    <Link to={`/posts?${ (new URLSearchParams ({ tags: tag.name })).toString () }`}
                          className="text-blue-600 hover:underline">
                      {tag.name}
                    </Link>
                    {posts.length > 1 && <span className="ml-1">{tagsCounts[tag.id]}</span>}
                  </li>))}
            </ul>
            </>)}
      </div>)
}

export default TagSidebar
