import React, { useEffect, useState } from 'react'
import { Link, useLocation, useParams } from 'react-router-dom'
import axios from 'axios'
import { API_BASE_URL, SITE_TITLE } from '../config'
import NicoViewer from '../components/NicoViewer'

type Tag = { id:        number
             name:      string
             category:  string }

type Post = { id:         number
              url:        string
              title:      string
              thumbnail:  string
              tags:       Tag[] }

type Props = { posts:     Post[]
               setPosts:  (posts: Post[]) => void }


const PostDetailPage = (props: Props) => {
  const { posts, setPosts } = props
  const { id } = useParams ()

  const location = useLocation ()

  useEffect (() => {
    if (!(id))
      return
    void (axios.get (`/api/posts/${ id }`)
          .then (res => setPosts ([res.data]))
          .catch (err => console.error ('うんち!', err)))
  }, [id])

  if (!(posts.length))
    return <div>Loading...</div>

  const post = posts[0]

  document.title = `${ post.title || post.url } | ${ SITE_TITLE }`

  const url = new URL (post.url)

  return (
      <div className="p-4">
        {(() => {
          if (url.hostname.split ('.').slice (-2).join ('.') === 'nicovideo.jp')
            {
              return (
                  <NicoViewer
                    id={url.pathname.match (
                          /(?<=\/watch\/)[a-zA-Z0-9]+?(?=\/|$)/)[0]}
                    width="640"
                    height="360" />)
            }
          else
            return <img src={post.thumbnail} alt={post.url} className="mb-4 w-full" />
        }) ()}
      </div>)
}


export default PostDetailPage
